# Documentation string. I wonder what ever refers to it? 

__doc__ = """ZMailIn product module.

This module provides the methods and classes that Zope needs for the product. 
__init__.py is responsible for registering these methods and classes.
"""

# Version string. Usually updated automatically by CVS. 

__version__ = '0.2' 

# Now, you can compress these imports down to three lines, but that makes it 
# harder to document it as you go. Here's the long-winded version: 

from Globals import HTMLFile      # fakes a method from a DTML file
from Globals import MessageDialog # provid
from Globals import Persistent    # makes an object stick in the ZODB

import OFS.SimpleItem
import Acquisition
import AccessControl.Role

"""Step #1: Provide "constructors" for Zope's management interface. 
__init__ is all very well and good for Python, but doesn't provide 
a nice HTML interface or accept arguments from an HTTP request, so 
you need to provide some functions to act as a middle-man between 
Zope and your class.

Use HTMLFile to produce a [pseudo-]function which hands back an 
appropriate DTML document based on a file sitting in your product 
directory. 
"""

manage_addZMailInForm = HTMLFile('ZMailInAdd', globals()) 

def manage_addZMailIn(self, id, title='', email='', method='', REQUEST=None):
    """Add a ZMailIn to a folder."""
    self._setObject(id, ZMailIn(id, title, email, method, REQUEST))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

"""Step #2: Provide the class for your ZMailIn object."""

class ZMailIn(
    OFS.SimpleItem.Item,   # A simple Principia object. Not Folderish. 
    Persistent,            # Make us persistent. Yaah! 
    Acquisition.Implicit,  # Uh, whatever. 
    AccessControl.Role.RoleManager # Security manager. 
    ): 
    """ZMailIn object. 
    
    This is an attempt at writing a product from scratch using mostly 
    Python instead of ZClasses. We'll see how it all goes.
    """
        
    meta_type = 'ZMailIn Client' # what people are adding? 

    manage_options = ( # what management options are there?
	{'label': 'Edit',       'action': 'manage_main'},
	{'label': 'View',       'action': ''}, # defaults to index_html
	{'label': 'Security',   'action': 'manage_access'},
        ) 

    __ac_permissions__=( # what permissions make sense for us? 
	('View management screens', ('manage_tabs','manage_main')),
	('Change permissions',      ('manage_access',)           ),
	('Change ZMailIn'     ,     ('manage_edit',)             ),
	('View ZMailIn',            ('',)                        ),
	)

    def __init__(self, id, title='', email='', method='',REQUEST=None): 
        """initialise a new instance of ZMailIn"""
        import string, os
        
        self.id = id
        self.title = title
        self.email = email
        self.method = method
        
        # This bit sucks, I know.  What I am trying to do is get the home
        # Directory for the zope instance, I used to use INSTANCE_HOME from
        # the REQUEST but thats seems to have been removed in 2.1.6 up.
        # So what I am doing now is getting the directory in which this
        # script is running.
        # ie: /usr/local/zope/lib/python/Products/ZMailIn/
        # and chooping it back just behind the lib/python to read
        # /usr/local/zope/
        # If you know a better way of doing this email me andyd@nipltd.com
        
        # zopedir = REQUEST.environ.get('INSTANCE_HOME','InstanceHomeNotFound')
        zopedir = os.getcwd()[:string.find(os.getcwd(),'lib/python')+1]
        
        currentlocation = REQUEST.environ.get('PATH_INFO','PathInfoNotFound')
        currentlocation = currentlocation[:string.find(currentlocation,'/manage_addProduct')]
        f = open(zopedir+'var/ZMailIn.loc',"a")
        f.write(self.email+' = '+currentlocation+'/'+self.id+'\n')
        f.close()

    index_html = HTMLFile('index', globals()) # View Interface
    
    manage_main = HTMLFile('ZMailInEdit', globals()) # Management Interface
    
    def manage_edit(self, title, email, method, REQUEST=None): 
    	""" Edit """
        self.title = title
        self.email = email
        self.method = method
	if REQUEST is not None:
	    return MessageDialog(
		title = 'Edited',
		message = "Properties for <I>%s</I> changed." % self.id,
		action = './manage_main',
		)
		
    def postZMailMessage(self, id='temp', title='', subject='', date='Tue, 13 Jun 2000 09:34:08 +0100', to='', sender='', replyto='', body='', headers=''):
        """ 
        This method will create a folder for the year/month/day and store the Mail Message in that folder.
        This is a temporary measure for version 0.2 in later version the plan is to hand the mail message
        (or the data for the mail message) to a specific method stated in the ZMailIn client
        """
	import rfc822, time
	
	self=self.this()
	parent = self.aq_parent
	
	datetuple = rfc822.parsedate(date)
	day = time.strftime('%d', datetuple)
	month = time.strftime('%B', datetuple)
	year = time.strftime('%Y', datetuple)
		
	if year not in parent.objectIds():
		parent.manage_addFolder(year)

	yearfolder = parent[year]
			
	if month not in yearfolder.objectIds():
		yearfolder.manage_addFolder(month)

	monthfolder = yearfolder[month]

	if day not in monthfolder.objectIds():
		monthfolder.manage_addFolder(day)

	dayfolder = monthfolder[day]
	
	x = dayfolder.manage_addProduct['ZMailMessage']
	x.manage_addZMailMessage(dayfolder, id, title, subject, date, to, sender, replyto, body, headers)
	
	# xmlrpc throws a paddy if you don't return a string, so here goes
	return 'OK!'	
