# Documentation string. I wonder what ever refers to it? 

__doc__ = """ZMailMessage product module.

This module provides the methods and classes that Zope needs for the product. 
__init__.py is responsible for registering these methods and classes.
"""

# Version string. Usually updated automatically by CVS. 

__version__ = '0.2'

# Now, you can compress these imports down to three lines, but that makes it 
# harder to document it as you go. Here's the long-winded version: 

from Globals import HTMLFile      # fakes a method from a DTML file
from Globals import MessageDialog # provid
from Globals import Persistent    # makes an object stick in the ZODB

import OFS.SimpleItem
import Acquisition
import AccessControl.Role

"""Step #1: Provide "constructors" for Zope's management interface. 
__init__ is all very well and good for Python, but doesn't provide 
a nice HTML interface or accept arguments from an HTTP request, so 
you need to provide some functions to act as a middle-man between 
Zope and your class.

Use HTMLFile to produce a [pseudo-]function which hands back an 
appropriate DTML document based on a file sitting in your product 
directory. 
"""

manage_addZMailMessageForm = HTMLFile('ZMailMessageAdd', globals()) 

def manage_addZMailMessage(self, id, title='', subject='', date='', to='', sender='', replyto='', body='', headers='', REQUEST=None):
    """Add a ZMailMessage to a folder."""
    self._setObject(id, ZMailMessage(id, title, subject, date, to, sender, replyto, body, headers))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

"""Step #2: Provide the class for your ZMailMessage object."""

class ZMailMessage(
    OFS.SimpleItem.Item,   # A simple Principia object. Not Folderish. 
    Persistent,            # Make us persistent. Yaah! 
    Acquisition.Implicit,  # Uh, whatever. 
    AccessControl.Role.RoleManager # Security manager. 
    ): 
    """ZMailMessage object. 
    
    This is an attempt at writing a product from scratch using mostly 
    Python instead of ZClasses. We'll see how it all goes.
    """
        
    meta_type = 'ZMailMessage' # what do people think they're adding? 

    manage_options = ( # what management options are there?
	{'label': 'View',       'action': ''}, # defaults to index_html
	{'label': 'Edit',       'action': 'manage_main'},
	{'label': 'Security',   'action': 'manage_access'},
        ) 

    __ac_permissions__=( # what permissions make sense for us? 
	('View management screens', ('manage_tabs','manage_main')),
	('Change permissions',      ('manage_access',)           ),
	('Change ZMailMessages',    ('manage_edit',)             ),
	('View ZMailMessage',       ('',)                        ),
	)

    def __init__(self, id, title='', subject='', date='', to='', sender='', replyto='', body='', headers=''): 
        """initialise a new instance of ZMailMessage"""
        self.id = id
        self.title = title
        self.subject = subject
        self.date = date
        self.to = to
        self.sender = sender
        self.replyto = replyto
        self.body = body
        self.headers = headers

    index_html = HTMLFile('index', globals()) # View Interface
    
    manage_main = HTMLFile('ZMailMessageEdit', globals()) # Management Interface
    
    def manage_edit(self, title, subject, date, to, sender, replyto, body, headers, REQUEST=None): 
        """does this really need a doc string?"""
        self.title = title
        self.subject = subject
        self.date = date
        self.to = to
        self.sender = sender
        self.replyto = replyto
        self.body = body
        self.headers = headers
	if REQUEST is not None:
	    return MessageDialog(
		title = 'Edited',
		message = "Properties for <I>%s</I> changed." % self.id,
		action = './manage_main',
		)
